<?php

namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Teknisa\EST\Controllers\TeknisaCrud;
use Teknisa\EST\Modules\Relatorios\Services\Est31300MovimentacaoDeEstoqueService;


class Est31300MovimentacaoDeEstoqueController extends TeknisaCrud {
    protected $newCode;
    protected $reportService;
    protected $environment;
    protected $dataSourceName = "parammovest_tiporeti";
    protected $dataSourceNameToSave = 'parammovest';
    protected $parameterBagColumns = [
    	"NRORG",
        "CDTIPORETI", 
        "NMTIPORETI",
        "CDCOLUNAMOVEST",
        "NMCOLUNAMOVEST",
        "CDTPRETIMOVEST"
	];

    public function __construct($newCode, $environment, ReportService $reportService, $crudService, Est31300MovimentacaoDeEstoqueService $moviestService) {
        $this->newCode       = $newCode;
        $this->environment   = $environment;
        $this->reportService = $reportService;
        $this->crudService   = $crudService;
        $this->moviestService = $moviestService;
    }
    
    
    public function findParams(DTO\Request\Filter $request, DTO\Response $response) {
        $dataSet = $this->crudService->getFilteredDataSet('parammovest_tiporeti', []);
        
        $rows = $dataSet->getRows();
        
        $fieldsToset = ["CDTIPORETI", "NMTIPORETI", "CDCOLUNAMOVEST", "NMCOLUNAMOVEST"];
        $DatasetResponse = array();
        foreach($fieldsToset as $field){
            $tmpArray = array();
            foreach($rows as $row){
                array_push($tmpArray, $row[$field]);
            }
                $DatasetResponse[$field] = $tmpArray;
        }
        
        $tmpArray = array();
        $vendas = array_filter($rows, function($row){
           return $row['CDCOLUNAMOVEST'] == 'VE';
        });
        $vendas = array_values($vendas);
        foreach($vendas as $venda){
           array_push($tmpArray, $venda['CDTPRETIMOVEST']);
        }
        $DatasetResponse['VENDAS'] = $tmpArray;
        
        $tmpArray = array();
        $quebras = array_filter($rows, function($row){
           return $row['CDCOLUNAMOVEST'] == 'QU';
        });
        $quebras = array_values($quebras);
        foreach($quebras as $quebra){
           array_push($tmpArray, $quebra['CDTPRETIMOVEST']);
        }
        $DatasetResponse['QUEBRA'] = $tmpArray;
        
        $tmpArray = array();
        $consumos = array_filter($rows, function($row){
           return $row['CDCOLUNAMOVEST'] == 'CO';
        });
        $consumos = array_values($consumos);
        foreach($consumos as $consumo){
           array_push($tmpArray, $consumo['CDTPRETIMOVEST']);
        }
        $DatasetResponse['CONSUMO'] = $tmpArray;
        
        $response->addDataset(new DataSet('getParamsMoviest', array($DatasetResponse)));
    }
    
    public function saveParams(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
    
        $nrorg = $this->environment->getNrOrgTrab();
        $typesToInsert = ['VENDAS', 'QUEBRA', 'CONSUMO'];
        $dataSetToSave = array();
        $this->moviestService->deleteAllParams();
        foreach($typesToInsert as $type){
            foreach($row[$type] as $codReti){
                $rowToSave['__is_new'] = true;
                $rowToSave['CDCOLUNAMOVEST'] = $type == 'VENDAS'? 'VE' : ($type == 'QUEBRA'? 'QU' : 'CO');
                $rowToSave['NMCOLUNAMOVEST'] = $type;
                $rowToSave['CDTPRETIMOVEST'] = $codReti;
                array_push($dataSetToSave, $rowToSave);
            }
        }
        $dataSetToSave = new DataSet('parammovest', $dataSetToSave);
        $newRequest = new DTO\Request\DataSet ($dataSetToSave, '', '', '');
	    parent::save($newRequest, $response);
    }
    
    public function generateReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrgTrab();
        

        if(is_array($row["CDFILIAL"]) && $row['CDFILIAL'][0]){
            $concatenated = '_';
            
            foreach($row['CDFILIAL'] as $filial){
                $concatenated = $concatenated.$filial.'_';
            }
            $row['CDFILIAL'] = $concatenated;
        }

        $reportStrategy = array (
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "SEQUMOVI"     => "P_SEQUMOVI",
                "CDFILIAL"     => "P_CDFILIAL",
                "DTPERINI"     => "P_DTINICIAL",
                "DTPERFIN"     => "P_DTFINAL",
                "NRORG"        => "P_NRORG"
            )
        );
        $reportList = array(
            'Est31300MovEstoque',
            'Est31300MovEstoqueSintetico',
            'Est31400MovEstoqueConsolidadoAnali',
            'Est31400MovEstoqueConsolidadoSint',
            'Est31300MovEstoqueSinteticoQuantidade',
            'Est31300SintCons'
            
        );
        
        if($this->array_somee($reportList, $row['REPORT_NAME'])) {
            $row['SEQUMOVI'] = $this->newCode->getCodeByTableName('MOVIESTOQUE', $this->environment->getNrOrgTrab());
            $reportStrategy['parameterMapping']['CUSTOS']        = "P_CUSTO";
            $reportStrategy['parameterMapping']['CDALMOXARIFE']  = "P_CDALMOXARIFE";
            $reportStrategy['parameterMapping']['CDLOCALESTOQ']  = "P_CDLOCALESTOQ";
            $reportStrategy['parameterMapping']['NRLOTEESTQ']    = "P_NRLOTEESTOQ";
            $reportStrategy['parameterMapping']['NPTOTALIZA']    = "P_NPTOTALIZA";
            $reportStrategy['parameterMapping']['IDLANCTO']      = "P_IDLANCTO";
            $reportStrategy['parameterMapping']['CDPRODINI']     = "P_CDPRODINI";
            $reportStrategy['parameterMapping']['CDPRODFIN']     = "P_CDPRODFIN";
            $reportStrategy['parameterMapping']['EXIBE']         = "P_EXIBE";
            $reportName = ($row['REPORT_NAME'] === 'Est31300MovEstoque') ? 'EST31300' : 'EST31300SINTETICO';
            switch ($row['REPORT_NAME']) {
                case 'Est31300MovEstoque':
                    $reportName = 'EST31300';
                    break;
                case 'Est31300MovEstoqueSintetico': 
                    $reportName = 'EST31300SINTETICO';
                    break;
                case 'Est31400MovEstoqueConsolidadoAnali':
                    $reportName = 'EST31400';
                    break;
                case 'Est31400MovEstoqueConsolidadoSint':
                    $reportName = 'EST31400SINTETICO';
                    break;
                case 'Est31300MovEstoqueSinteticoQuantidade':
                    $reportName = 'EST31300SINTETICOQUANTIDADE';
                    break;
                
            }
        }
        else {
            date_default_timezone_set('America/Sao_Paulo');
            // $dataEmissao = date('d/m/Y H:i');
            $dataEmissao = date('d/m/Y');
            $reportStrategy['parameterMapping']['DTEMISSAO']      = "P_DTEMISSAO";
            $reportStrategy['parameterMapping']['PRODINI']        = "P_PRODINI";
            $reportStrategy['parameterMapping']['PRODFIN']        = "P_PRODFIN";
            $row['P_DTEMISSAO'] = $dataEmissao;

            if($row['REPORT_NAME'] == 'Est31300MovEstoqueApInventario'){
                $reportName = 'EST31301';
                $reportStrategy['parameterMapping']['CDGRUPPROD']     = "P_CDGRUPPROD";
            }
            else
                $reportName = $row['REPORT_NAME'];
        }
        
        $parametersRow = array();

        foreach ($reportStrategy['parameterMapping'] as $fieldName => $paramName) {
            
            if ($row->has($fieldName)) $parametersRow[$paramName] = $row->get($fieldName);
        }
     
        if($reportName === 'EST31301' || $reportName === 'EST31308Movdiaria') {
            $parametersRow['P_DTEMISSAO'] = $dataEmissao;
            $parametersRow['P_PRODINI'] = isset($row['CDPRODINI'])? $row['CDPRODINI'] : null;
            $parametersRow['P_PRODFIN'] = isset($row['CDPRODFIN'])? $row['CDPRODFIN'] : null;
            $parametersRow['P_CDGRUPPROD'] = isset($row['CDGRUPPROD'])?  $row['CDGRUPPROD'] : null;
        }
        else {
            $parametersRow['P_CDPRODINI'] = $row['CDPRODINI'];
            $parametersRow['P_CDPRODFIN'] = $row['CDPRODFIN'];
        }
        
        if($reportName === 'EST31308Movdiaria'){ 
            $parametersRow['P_NMPRODINI'] = $row['NMPRODINI'];
            $parametersRow['P_NMPRODFIN'] = $row['NMPRODFIN'];
        }
        $parametersRow['P_NRORG'] = $nrorg;
        
        if($row['HEADER_DESCR'] == 'N') 
            $reportName = $reportName.'_noHeader';
            
        $parametersRow['__format'] = $row["__FORMAT"];
        
        $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow);
        $response->addDataset(new DataSet('URL',array($birtURL)));
    }
    
    
        
    public function array_somee(array $array, $fn) {
        foreach ($array as $value) {
            if($value == $fn) {
                return true;
            }
        }
        return false;
    }
    
    
}