<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Filter;
use Teknisa\EST\Modules\Relatorios\Services\Ger09700ProjecaoDeEstoqueService;
use Teknisa\EST\Controllers\TeknisaCrud;

class Ger09700ProjecaoDeEstoqueController extends TeknisaCrud {
    
    protected $crudService;
	protected $dataSourceManager;
	protected $parameterBag;
	protected $environment;
    protected $gerService;
    protected $dataSourceName;
    protected $parameterBagColumns = array("P_CDFILESTPROJ", "P_NRSEQESTPROJ", "P_DTPERLEVINI", "P_DTPERLEVFIN");
    
    public function __construct($crudService, $parameterBag, $dataSourceManager, $environment, Ger09700ProjecaoDeEstoqueService $gerService) {
        parent::__construct($crudService,$parameterBag);
        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
        $this->gerService = $gerService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        //PARAMETROS
        $P_FILIPROC = null;
        $P_CDFILIAL = null;
        $P_DTLEVINI = null;
        $P_DTLEVFIN = null;
        $P_PRODINI = null;
        $P_PRODFIN = null;
        $P_FILESTOQ = null;
        $P_IDGERSOL = null;
        $P_CONSSOL = null;
        $P_CONSAF = null;
        $P_CONSEST = null;
        $P_CONSROM = null;
        $P_FILIROM = null;
        $P_SERIROM = null;
        $P_OPERADOR = null;
        $P_NRSEQESTPROJ = null;
        
        $filterCriteria = $request->getFilterCriteria();
        $conditions = $filterCriteria->getConditions();
        
        foreach($conditions as $condition) {
            if($condition["columnName"] == "CDFILIAL") {
                $P_FILIPROC = $this->environment->getCdFilial();
                $P_CDFILIAL = $condition["value"];
            } else if($condition["columnName"] == "DTLEV") {
                $P_DTLEVINI = $condition["value"][0];
                $P_DTLEVFIN = $condition["value"][1];
            } else if($condition["columnName"] == "CDPRODINI") {
                $P_PRODINI = $condition["value"];
            } else if($condition["columnName"] == "CDPRODFIN") {
                $P_PRODFIN = $condition["value"];
                $P_PRODFIN = $P_PRODFIN . "ZZZZZZZZZZZZZZZZZZZZ";
                $P_PRODFIN = substr($P_PRODFIN, 0, 20);
            } else if($condition["columnName"] == "TFILESTOQ") {
                if($condition["value"] == 'T') {
                    $P_FILESTOQ = null;
                }
            } else if($condition["columnName"] == "NMFILESTOQ") {
                if(is_array($condition["value"])) {
                    if(count($condition["value"]) != 0) {
                        $filialstr = '_';
                        foreach($condition["value"] as $filial) {
                            $filialstr .= $filial . '_';
                        }
                        $P_FILESTOQ = $filialstr;
                    } else {
                        $P_FILESTOQ = null;
                    }
                } else {
                    $P_FILESTOQ = null;
                }
            } else if($condition["columnName"] == "GERSOL") {
                $P_IDGERSOL = $condition["value"];
            } else if($condition["columnName"] == "CONSSOL") {
                $P_CONSSOL = $condition["value"];
            } else if($condition["columnName"] == "CONSAF") {
                $P_CONSAF = $condition["value"];
            } else if($condition["columnName"] == "CONSEST") {
                $P_CONSEST = $condition["value"];
            } else if($condition["columnName"] == "CONSROM") {
                $P_CONSROM = $condition["value"];
            } else if($condition["columnName"] == "TFILIROM") {
                if($condition["value"] == 'T') {
                    $P_FILIROM = null;
                }
            } else if($condition["columnName"] == "NMFILIROM") {
                if(is_array($condition["value"])) {
                    if(count($condition["value"]) != 0) {
                        $filialstr = '_';
                        foreach($condition["value"] as $filial) {
                            $filialstr .= $filial . '_';
                        }
                        $P_FILIROM = $filialstr;
                    } else {
                        $P_FILIROM = null;
                    }
                } else {
                    $P_FILIROM = null;
                }
            } else if($condition["columnName"] == "TSERIROM") {
                if($condition["value"] == 'T') {
                    $P_SERIROM = 'T';
                }
            } else if($condition["columnName"] == "DSSERIE") {
                if(is_array($condition["value"])) {
                    if(count($condition["value"]) != 0) {
                        $seriestr = '_';
                        foreach($condition["value"] as $serie) {
                            $seriestr .= $serie . '_';
                        }
                        $P_SERIROM = $seriestr;
                    } else {
                        $P_SERIROM = null;
                    }
                } else {
                    $P_SERIROM = null;
                }
            } else if($condition["columnName"] == "CDOPERADOR") {
                $P_OPERADOR = $condition["value"];
            }
        }
        
        if($P_PRODFIN == null) {
            $P_PRODFIN = "ZZZZZZZZZZZZZZZZZZZZ";
        }
        
        // var_dump($P_FILIPROC);
        // var_dump($P_CDFILIAL);
        // var_dump($P_DTLEVINI);
        // var_dump($P_DTLEVFIN);
        // var_dump($P_PRODINI);
        // var_dump($P_PRODFIN);
        // var_dump($P_FILESTOQ);
        // var_dump($P_IDGERSOL);
        // var_dump($P_CONSSOL);
        // var_dump($P_CONSAF);
        // var_dump($P_CONSEST);
        // var_dump($P_CONSROM);
        // var_dump($P_FILIROM);
        // var_dump($P_SERIROM);
        // var_dump($P_OPERADOR);
        
        $P_NRSEQESTPROJ = $this->gerService->executaProcedureProjecaoDeEstoque(
            $P_FILIPROC,
            $P_CDFILIAL,
            $P_DTLEVINI,
            $P_DTLEVFIN,
            $P_PRODINI,
            $P_PRODFIN,
            $P_FILESTOQ,
            $P_IDGERSOL,
            $P_CONSSOL,
            $P_CONSAF,
            $P_CONSEST,
            $P_CONSROM,
            $P_FILIROM,
            $P_SERIROM,
            $P_OPERADOR
        );
        
        // var_dump("PROCEDURE: ".$P_NRSEQESTPROJ);
        
        $filter = array(
            array(
                "columnName"=>"P_CDFILESTPROJ",
                "value"=>$P_FILIPROC,
                "operator"=>"="
            ),
            array(
                "columnName"=>"P_NRSEQESTPROJ",
                "value"=>$P_NRSEQESTPROJ,
                "operator"=>"="
            ),
            array(
                "columnName"=>"P_DTPERLEVINI",
                "value"=>$P_DTLEVINI,
                "operator"=>"="
            ),
            array(
                "columnName"=>"P_DTPERLEVFIN",
                "value"=>$P_DTLEVFIN,
                "operator"=>"="
            )
        );
        
        $this->dataSourceName = "projeta_estoque";
        
        $newFilterCriteria = new FilterCriteria($this->dataSourceName, $filter);
        $newRequest = new Filter($newFilterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
    
        parent::find($newRequest, $response);
        
        $this->gerService->executaDeleteProjecaoDeEstoque($P_FILIPROC, $P_NRSEQESTPROJ);
    }
}