<?php

/**
 * GepTextosolifluxoLogic.
 *
 * @package Logic
 * @author  erikasouza
 *
 */
class GepTextosolifluxoLogic{


    private $_GepTextosolifluxoEntity;
    private $_GepTextosoliLogic;


    /**
     * Construtor da Classe.
     */
    public function __construct(){
        $this->_GepTextosolifluxoEntity = new GepTextosolifluxoEntity();
        $this->_GepTextosoliLogic       = new GepTextosoliLogic();
    }


    /**        OK
     * Retorna lista com a parametrizacao de um determinado tipo de fluxo.
     *
     * @param integer $nrorg    Numero da Organizacao.
     * @param integer $tp_fluxo Tipo do fluxo.
     *
     * @return Ambigous <boolean, NULL, TkModelEntity>|boolean
     */
    public function retornaDadosTextoFluxo($nrorg, $tp_fluxo){
        try {
            $dados = $this->_GepTextosolifluxoEntity->retornaDadosTextoFluxo($nrorg, $tp_fluxo);
            return $dados;
        } catch (Exception $e) {
            switch ($e->getCode()){
            case GepTextosolifluxoEntity::SEM_REGISTRO:
                return GepTextosolifluxoEntity::SEM_REGISTRO;
            default:
                tk_warning('Erro desconhecido: '.$e->getMessage());
                return false;
            }
        }
    }


    /**
     * Retorna dados de um texto por fluxo de acordo com a sua PK.
     *
     * @param integer $nrorg   Numero da Organizacao.
     * @param integer $nrtexto Codigo do texto.
     *
     * @return GepTextosolifluxoEntity
     */
    public function retornaDadosTextoFluxoPk($nrorg, $nrtexto){
        $dados = $this->_GepTextosolifluxoEntity->retornaDadosTextoFluxoPk($nrorg, $nrtexto);
        return $dados;
    }


    /**
     * Gera novo codigo de Texto da solicitacao do tipo de fluxo.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return $codigo integer
     */
    public static function retornaProxNumeroTextosolifluxo($nrorg){
        $dados = GepTextosolifluxoEntity::retornaProxNumeroTextosolifluxo($nrorg);
        return $dados;
    }


    /**      ok
     * Insere os textos parametrizados no GEP_TEXTOSOLIFLUXO no GEP_TEXTOSOLI se nao houver texto inserido no
     * GEP_TEXTOSOLI.
     *
     * @param integer $nrorg    Numero da organizacao.
     * @param date    $data     Data.
     * @param integer $operador Codigo do operador.
     * @param integer $tp_fluxo Tipo do fluxo.
     * @param integer $soli     Numero da solicitacao.
     *
     * @return boolean
     */
    public function insereTextosParametrizados($nrorg, $data, $operador, $tp_fluxo, $soli){
        $dados_textosoli = $this->_GepTextosoliLogic->retornaDadosTextoSoli($nrorg, $soli);

        if ($dados_textosoli === GepTextosoliEntity::SEM_REGISTRO) {
            $dados_textofluxo = $this->retornaDadosTextoFluxo($nrorg, $tp_fluxo);

            if ($dados_textofluxo !== false AND $dados_textofluxo !== GepTextosolifluxoEntity::SEM_REGISTRO) {
                foreach ($dados_textofluxo as $dados) {
                    $ordem = $dados->getNrordenatextosoli();
                    $grupo = $dados->getDsgrupotextosoli();
                    $titulo = $dados->getDstitulotextosoli();
                    $texto = $dados->getTxsolicitacao();
                    $exclui_texto = $dados->getIdexcluitextosoli();
                    $alt_ordenacao = $dados->getIdalteraordenatexto();
                    $alt_grupo = $dados->getIdalteragrupotexto();
                    $alt_titulo = $dados->getIdalteratitulotexto();

                    if ($texto === null) {
                        $texto = 'Insira o seu texto aqui';
                    }

                    $observ = $dados->getDsobservtextosoli();

                    $insere_textosoli = $this->_GepTextosoliLogic->insereTextosSoli(
                        $soli, $ordem, $grupo, $titulo, $texto, $observ, $nrorg, $data,
                        $operador, $exclui_texto, $alt_ordenacao, $alt_grupo, $alt_titulo
                    );
                }

                return true;
            }
        }

        return false;
    }


}